//VogelBoxTrays3

nanoBoardWidth = 18.7;
nanoBoardLength = 43.7;
nanoBoardThick = 1.6;
nanoBoardComponentThick = 2.51;
pMicroBoardLength = 33.5;
pMicroBoardWidth = 18.7;
microBoardLength = 48.0;

backComponentMargin = 2.5;

bottomThick = 1.0;
wallThick = 1.0;

mp3tfWidth = 20.8;
mp3tfLength = 20.5;
mp3tfBoardThick = 1.6;
mp3tfComponentThick = 2.0;
mp3tfTrayLength = 27.0;
mp3tfTrayThick = 5.5;

mp3tfTrayWidth = 30.0;
trayLength = 45.0;
trayThick = 6.2;

buttonTrayWidth = 26.0;
buttonTrayThick = 1.5;
buttonTrayLength = trayLength - 33;
buttonXoffset = 2.0;
buttonWidth = 5.5;
buttonHeight = 5.5;
buttonDepth = 4.0 + 1.6 + buttonHeight / 2;
buttonPCBHeight = 8.0;

sideMountHoleDiam = 2.1;
sideMountHoleOffset = 2.0;

panelThick = 2.0;
panelHeight = 25.0;

// The nanoTray and pMicroTray are part of the VogelBox2Lid, other trays are separate
//translate([0, panelThick, 0]) nanoTray();

//translate([0, panelThick, 00]) pMicroTray();

translate([0, panelThick, trayThick]) mp3tfTray();

//translate([0, panelThick, trayThick + mp3tfTrayThick]) buttonTray();

//color("lightblue") panel(panelThick);

//translate([0, 5.0, trayThick]) color("red") cylinder(d = 5, h = 2);

module panel(boxWall) {
    buttonHole = 4.25;
    buttonHeight = 18.75;
    inch10 = 2.54;
    holeZoffset = 1;
    sizeRedux = -0.2;
    difference() {
        translate([mp3tfTrayWidth/2 - 1, 0, panelHeight/2 - boxWall/2 + holeZoffset]) rotate([-90, 180, 0]) 
            panelBase(mp3tfTrayWidth, panelHeight, boxWall, sizeRedux);
        // panel cutout
        translate([mp3tfTrayWidth/2 - boxWall/2, -0.1, panelHeight/2 - boxWall + holeZoffset + 0.5]) rotate([-90, 0, 0]) 
            panelFrontCutout(mp3tfTrayWidth - boxWall*2, boxWall, panelHeight - boxWall *2);
            //cube([mp3tfTrayWidth - boxWall * 3, boxWall/2 + 0.02, panelHeight - boxWall *2]);
        // usb micro 
        translate([8.5, -0.01, 3.0]) cube([10.0, panelThick + 0.02, 3.5]);
        // sd card
        translate([5.25, -0.01, 10.0]) cube([16.0, panelThick + 0.02, 2.25]);
        // buttons
        translate([7.0, -0.01, buttonHeight]) rotate([-90, 0, 0]) cylinder(d = buttonHole, h = panelThick + 0.02, $fn = 32);
        translate([7.0 + 5 * inch10, -0.01, buttonHeight]) rotate([-90, 0, 0]) cylinder(d = buttonHole, h = panelThick + 0.02, $fn = 32);
    }
}

module panelFrontCutout(width, thick, height) {
    hull() {
        translate([0, -height/2, 0]) {
            translate([-width/2, 0, 0]) cylinder(d1 = thick/2, d2 = 0.01, h = thick/2);
            translate([ width/2, 0, 0]) cylinder(d1 = thick/2, d2 = 0.01, h = thick/2);
        }
        translate([0, height/2, 0]) {
            translate([-width/2, 0, 0]) cylinder(d1 = thick/2, d2 = 0.01, h = thick/2);
            translate([ width/2, 0, 0]) cylinder(d1 = thick/2, d2 = 0.01, h = thick/2);
        }
    }
}

module nanoBoard() {
    // solder side components
    translate([backComponentMargin, 0, 0]) 
        cube([nanoBoardWidth - backComponentMargin * 2, nanoBoardLength, nanoBoardThick]);
    // board + components
    translate([0, 0, nanoBoardThick]) 
        cube([nanoBoardWidth, nanoBoardLength, nanoBoardThick + nanoBoardComponentThick]);
}

module pMicroBoard() {
    // solder side components
    translate([backComponentMargin, 0, 0]) 
        cube([pMicroBoardWidth - backComponentMargin * 2, pMicroBoardLength, nanoBoardThick]);
    // board + components
    translate([0, 0, nanoBoardThick]) 
        cube([pMicroBoardWidth, pMicroBoardLength, nanoBoardThick + nanoBoardComponentThick]);
}

module nanoTray() {
    extraWidth = 2.0;
    pcbWoffset = (mp3tfTrayWidth - nanoBoardWidth) / 2;
    pcbLoffset = trayLength - nanoBoardLength;
    pcbToffset = trayThick - (nanoBoardThick + nanoBoardThick); // pcb and back-side components
    difference() {
        translate([0, 0, 0]) cube([mp3tfTrayWidth, trayLength, trayThick]);
        translate([pcbWoffset, -0.01, 0.5]) nanoBoard();
        translate([0, 0, 0]) mountHoles();
    }
}

module pMicroTray() {
    extraWidth = 2.0;
    pcbWoffset = (mp3tfTrayWidth - pMicroBoardWidth) / 2;
    pcbLoffset = trayLength - nanoBoardLength;
    pcbToffset = trayThick - (nanoBoardThick + nanoBoardThick); // pcb and back-side components
    difference() {
        translate([0, 0, 0]) cube([mp3tfTrayWidth, trayLength, trayThick]);
        translate([pcbWoffset, -0.01, 0.5]) pMicroBoard();
        translate([0, 0, 0]) mountHoles();
    }
}

module mp3tfTray() {
    extraWidth = 2.0;
    pcbWoffset = (mp3tfTrayWidth - mp3tfWidth) / 2;
    pcbLoffset = trayLength - mp3tfLength;
    pcbToffset = mp3tfTrayThick - mp3tfBoardThick * 2 + 0.01;
    difference() {
        translate([0, 0, 0]) cube([mp3tfTrayWidth, mp3tfTrayLength, mp3tfTrayThick]);
        translate([pcbWoffset, -0.01, 0.5]) mp3tfBoard();
        mountHoles(2.7);
        translate([mp3tfLength - 9, mp3tfTrayWidth - 8.9, -0.01]) cube([6, 6, 3]);
    }    
}

module mp3tfBoard() {
    // solder side components
    translate([backComponentMargin, 0, 0]) 
        cube([mp3tfWidth - backComponentMargin * 2, mp3tfLength, mp3tfBoardThick]);
    // board
    translate([0, 0, mp3tfBoardThick]) 
        cube([mp3tfWidth, mp3tfLength, mp3tfBoardThick + mp3tfComponentThick + 1]);
}

module buttonTray() {
    difference() {
        union() {
            // tray plate
            translate([buttonXoffset, 0, 0]) {
                cube([mp3tfTrayWidth - buttonXoffset * 2, trayLength - 33, buttonTrayThick]); 
                // button back support
                translate([0, buttonDepth, buttonTrayThick])
                    cube([mp3tfTrayWidth - buttonXoffset * 2,  buttonTrayLength - buttonDepth, buttonPCBHeight]);
            }
//            translate([buttonOffset, buttonDepth, buttonTrayThick + buttonHeight / 2]) 
//                cube([buttonWidth, buttonTrayLength - buttonDepth, buttonHeight], true);
//            translate([trayWidth - buttonOffset, buttonDepth, buttonTrayThick + buttonHeight / 2]) 
//                cube([buttonWidth, buttonTrayLength - buttonDepth, buttonHeight], true);
        }
        // lid mount holes
        mountHoles(2.7);
        // solder holes
        translate([buttonXoffset, buttonDepth, buttonTrayThick + 1.5]) solderHoles();
        // mount hole
        translate([mp3tfTrayWidth / 2, buttonDepth - 0.01, 5.5])
            rotate([-90, 0, 0]) cylinder(d = 2.2, h = 10, $fn = 16);
    }   
}

module solderHoles() {
    inch01 = 2.54;
    translate([2.85, -0.01, 0]) {
        translate([inch01 * 0, 0, 0]) rotate([-90, 0, 0]) solderHoleShape();
        translate([inch01 * 3, 0, 0]) rotate([-90, 0, 0]) solderHoleShape();
        translate([inch01 * 5, 0, 0]) rotate([-90, 0, 0]) solderHoleShape();
        translate([inch01 * 8, 0, 0]) rotate([-90, 0, 0]) solderHoleShape();
    }
    translate([2.85, -0.01, inch01 * 2]) {
        translate([inch01 * 0, 0, 0]) rotate([-90, 0, 0]) solderHoleShape();
        translate([inch01 * 3, 0, 0]) rotate([-90, 0, 0]) solderHoleShape();
        translate([inch01 * 5, 0, 0]) rotate([-90, 0, 0]) solderHoleShape();
        translate([inch01 * 8, 0, 0]) rotate([-90, 0, 0]) solderHoleShape();
    }
}

module solderHoleShape() {
    $fn = 16;
    holeDiamMin = 1.5;
    holeDiamMax = 2.5;
    holeDepth = 1.25;    
    cylinder(d1 = holeDiamMax, d2 = holeDiamMin, h = holeDepth);
}

module trayLid() {
    difference() {
        cube([trayWidth, trayLength - 35, 0.5]);
        mountHoles();
    }
}

module mountHole(diam = sideMountHoleDiam) {
    cylinder(d = diam, h = 10, $fn = 32);
}

module mountHoles(diam = sideMountHoleDiam) {
    translate([sideMountHoleOffset, 5.0, -0.01]) mountHole(diam);
    translate([mp3tfTrayWidth - sideMountHoleOffset, 5.0, -0.01]) mountHole(diam);
    translate([sideMountHoleOffset, 25.0, -0.01]) mountHole(diam);
    translate([mp3tfTrayWidth - sideMountHoleOffset, 25.0, -0.01]) mountHole(diam);
}

module panelBase(width, height, boxWall, sizeRedux) {
    insideWidth = width;
    insideHeight = height;
    outsideWidth = width;
    outsideHeight = height;
    
    hull() {
        translate([0, 0, 0]) surfaceSize(outsideWidth, outsideHeight, boxWall, sizeRedux);
        translate([0, 0, boxWall/2]) middleSize(insideWidth, insideHeight, boxWall, sizeRedux);
        translate([0, 0, boxWall]) surfaceSize(outsideWidth, outsideHeight, boxWall, sizeRedux);
    }
}

module surfaceSize(width, height, boxWall, sizeRedux) {
    rad = 0.01;
    translate([-width/2 + sizeRedux/2, -height/2 + sizeRedux/2, 0]) sphere(r = rad);
    translate([-width/2 + sizeRedux/2, height/2 - boxWall/2, 0]) sphere(r = rad);
    translate([ width/2 - sizeRedux/2, -height/2 + sizeRedux/2, 0]) sphere(r = rad);
    translate([ width/2 - sizeRedux/2, height/2 - boxWall/2, 0]) sphere(r = rad);    
}

module middleSize(width, height, boxWall, sizeRedux) {
    rad = 0.01;
    translate([-width/2 - boxWall/2 + sizeRedux/2, - height/2, 0]) 
        sphere(r = rad);
    translate([-width/2 - boxWall/2 + sizeRedux/2,  height/2 - sizeRedux/2, 0]) 
        sphere(r = rad);
    translate([ width/2 + boxWall/2 - sizeRedux/2, -height/2, 0]) 
        sphere(r = rad);
    translate([ width/2 + boxWall/2 - sizeRedux/2,  height/2 - sizeRedux/2, 0]) 
        sphere(r = rad);
}